About
-----

This is a Python port of the SED fitter from Robitaille et al. (2006).

It is highly experimental - if you are interested in using it, please contact me.

Status
------

[![Build Status](https://travis-ci.org/astrofrog/sedfitter.png?branch=refactor-non-affiliated)](https://travis-ci.org/astrofrog/sedfitter)

[![Coverage Status](https://coveralls.io/repos/astrofrog/sedfitter/badge.png)](https://coveralls.io/r/astrofrog/sedfitter)